/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03088
 |           ALCOHOL AND DRUG SERVICES STUDY (ADSS), 1996-1999:
 |                            [UNITED STATES]
 |            (DATASET 0002: PHASE II ADMINISTRATOR INTERVIEW)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03088-0002-statasetup.do)
 |
 **************************************************************************/

set mem 6m  /* Allocating 6 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Alcohol and Drug Services Study (ADSS), 1996-1999: [United States], Phase II Administrator Interview"

#delimit ;
label define Q1        -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       99995 "99995 OR MORE CLIENTS" ;
label define Q2A       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q2B       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q2C       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q2D       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q3A       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 99995 "99995 OR MORE CLIENTS" ;
label define Q3B       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 99995 "99995 OR MORE CLIENTS" ;
label define Q3C       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 99995 "99995 OR MORE CLIENTS" ;
label define Q3D       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 99995 "99995 OR MORE CLIENTS" ;
label define Q3TOT     -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       99995 "99995 OR MORE CLIENTS" ;
label define Q4A       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT APPLICABLE (DO NOT HAVE)"
                       1 "YES (COPY OBTAINED)" ;
label define Q4B       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT APPLICABLE (DO NOT HAVE)"
                       1 "YES (COPY OBTAINED)" ;
label define Q4C       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT APPLICABLE (DO NOT HAVE)"
                       1 "YES (COPY OBTAINED)" ;
label define Q4D       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT APPLICABLE (DO NOT HAVE)"
                       1 "YES (COPY OBTAINED)" ;
label define Q4E       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT APPLICABLE (DO NOT HAVE)"
                       1 "YES (COPY OBTAINED)" ;
label define Q4F       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT APPLICABLE (DO NOT HAVE)"
                       1 "YES (COPY OBTAINED)" ;
label define Q4G       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT APPLICABLE (DO NOT HAVE)"
                       1 "YES (COPY OBTAINED)" ;
label define Q4H       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT APPLICABLE (DO NOT HAVE)"
                       1 "YES (COPY OBTAINED)" ;
label define Q4I       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT APPLICABLE (DO NOT HAVE)"
                       1 "YES (COPY OBTAINED)" ;
label define Q4J       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT APPLICABLE (DO NOT HAVE)"
                       1 "YES (COPY OBTAINED)" ;
label define Q4K       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT APPLICABLE (DO NOT HAVE)"
                       1 "YES (COPY OBTAINED)" ;
label define BOXA      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "BOX CHECKED" 2 "BOX NOT CHECKED" ;
label define BOXB      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "BOX CHECKED" 2 "BOX NOT CHECKED" ;
label define BOXC      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "BOX CHECKED" 2 "BOX NOT CHECKED" ;
label define BOXD      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "BOX CHECKED" 2 "BOX NOT CHECKED" ;
label define Q5A       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE BEDS" ;
label define Q5B       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE BEDS" ;
label define Q5C       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE BEDS" ;
label define Q6A       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE ADMISSIONS" ;
label define Q6B       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE ADMISSIONS" ;
label define Q6C       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE ADMISSIONS" ;
label define Q7A       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q7AU      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "DAYS" 2 "WEEKS" 3 "MONTHS" ;
label define Q7B       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q7BU      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "DAYS" 2 "WEEKS" 3 "MONTHS" ;
label define Q7C       -9 "INAPPLICABLE, Q7A AND Q7B ANSWERED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q7CU      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "DAYS" 2 "WEEKS" 3 "MONTHS" ;
label define Q8FMM     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q8FDD     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q8FYY     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q8TMM     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q8TDD     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q8TYY     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q9A       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q9B       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q9C       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q9D       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q10A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q11A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q10B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q11B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q10C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q11C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q10D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q11D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q10E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q10ES     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 96 "SPECIFIC SESSION CONTENT REPORTED" ;
label define Q11E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW"
                       -1 "DIFFERENT GROUPS, NUMBERS IN EACH GROUP" ;
label define Q12A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE BEDS"
                       9996 "NO SET NUMBER OF BEDS" ;
label define Q12B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE BEDS"
                       9996 "NO SET NUMBER OF BEDS" ;
label define Q12C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE BEDS"
                       9996 "NO SET NUMBER OF BEDS" ;
label define Q13A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE ADMISSIONS" ;
label define Q13B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE ADMISSIONS" ;
label define Q13C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE ADMISSIONS" ;
label define Q14       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q15A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q15AU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "DAYS" 2 "WEEKS" 3 "MONTHS"
                       4 "YEARS" ;
label define Q15B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q15BU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "DAYS" 2 "WEEKS" 3 "MONTHS"
                       4 "YEARS" ;
label define Q15C      -9 "INAPPLICABLE, Q15A AND Q15B ANSWERED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q15CU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "DAYS" 2 "WEEKS" 3 "MONTHS"
                       4 "YEARS" ;
label define Q16FMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q16FDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q16FYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q16TMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q16TDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q16TYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q17A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q17B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q17C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q17D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q18A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q19A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q18B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q19B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q18C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q19C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q18D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q19D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q18E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q18ES     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 96 "SPECIFIC SESSION CONTENT REPORTED" ;
label define Q19E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q20       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE ADMISSIONS" ;
label define Q21       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW"
                       -1 "MAJORITY OF CLIENTS STAY RANGES FROM 3 M" ;
label define Q21U      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "DAYS" 2 "WEEKS" 3 "MONTHS"
                       4 "YEARS" ;
label define Q22FMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q22FDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q22FYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q22TMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q22TDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q22TYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q23A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q23B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q24A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q25A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q24B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q25B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q24C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q25C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q24D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q25D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q24E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q24ES     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 96 "SPECIFIC SESSION CONTENT REPORTED" ;
label define Q25E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q26       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q27       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 9995 "9995 OR MORE ADMISSIONS" ;
label define Q28       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -1 "MORE THAN 1 LENGTH OF STAY GIVEN" ;
label define Q28U      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "DAYS" 2 "WEEKS" 3 "MONTHS"
                       4 "YEARS" 5 "SESSIONS" ;
label define Q29       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q30       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q31       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO PATIENTS STAYED FOR DETOX" ;
label define Q31U      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "DAYS" 2 "WEEKS" 3 "MONTHS" ;
label define Q32FMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q32FDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q32FYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q32TMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q32TDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q32TYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q33A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW"
                       -1 "VARIES BY CHARACTERISTICS OF CLIENT OR T" ;
label define Q33B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW"
                       -1 "VARIES BY CHARACTERISTICS OF CLIENT OR T" ;
label define Q34A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q35A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q34B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q35B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q34C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q35C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q34D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q35D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q34E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q34ES     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 96 "SPECIFIC SESSION CONTENT REPORTED" ;
label define Q35E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q36       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q37       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q38       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q39       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q40A      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q40B      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q40C      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q41       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q42A      -9 "INAPPLICABLE, CODED NO IN Q41" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q42B      -9 "INAPPLICABLE, CODED NO IN Q41" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q42C      -9 "INAPPLICABLE, CODED NO IN Q41" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q42D      -9 "INAPPLICABLE, CODED NO IN Q41" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q42E      -9 "INAPPLICABLE, CODED NO IN Q41" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q42F      -9 "INAPPLICABLE, CODED NO IN Q41" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q42G      -9 "INAPPLICABLE, CODED NO IN Q41" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q42H      -9 "INAPPLICABLE, CODED NO IN Q41" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q42I      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q42J      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q43       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q44       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q45       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "THIS FACILITY ONLY"
                       2 "INCLUDES OTHER ENTITIES" ;
label define Q45B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q45C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q46       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q46OTH1   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "FURNITURE/FURNISHINGS"
                       2 "EQUIPMENT" 3 "FOOD" 4 "BEDDING" 5 "CLOTHING"
                       6 "SPACE/UTILITIES" 7 "TAX RELIEF/TAX -EXEMPT STATUS"
                       8 "DISCOUNTED FACILITY RENTAL"
                       9 "VOLUNTEER SERVICES (NON-PROFESSIONAL, UN"
                       10 "PROFESSIONAL SERVICES"
                       11 "SUPPLIES (OFFICE, CLINICAL, EDUCATIONAL,"
                       12 "PATIENT GIFTS & ENTERTAINMENT" 96 "MISCELLANEOUS" ;
label define Q46OTH2   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "FURNITURE/FURNISHINGS"
                       2 "EQUIPMENT" 3 "FOOD" 4 "BEDDING" 5 "CLOTHING"
                       6 "SPACE/UTILITIES" 7 "TAX RELIEF/TAX -EXEMPT STATUS"
                       8 "DISCOUNTED FACILITY RENTAL"
                       9 "VOLUNTEER SERVICES (NON-PROFESSIONAL, UN"
                       10 "PROFESSIONAL SERVICES"
                       11 "SUPPLIES (OFFICE, CLINICAL, EDUCATIONAL,"
                       12 "PATIENT GIFTS & ENTERTAINMENT" 96 "MISCELLANEOUS" ;
label define Q46OTH3   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "FURNITURE/FURNISHINGS"
                       2 "EQUIPMENT" 3 "FOOD" 4 "BEDDING" 5 "CLOTHING"
                       6 "SPACE/UTILITIES" 7 "TAX RELIEF/TAX -EXEMPT STATUS"
                       8 "DISCOUNTED FACILITY RENTAL"
                       9 "VOLUNTEER SERVICES (NON-PROFESSIONAL, UN"
                       10 "PROFESSIONAL SERVICES"
                       11 "SUPPLIES (OFFICE, CLINICAL, EDUCATIONAL,"
                       12 "PATIENT GIFTS & ENTERTAINMENT" 96 "MISCELLANEOUS" ;
label define Q47BOX    -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "BOX IS CHECKED" 2 "BOX IS NOT CHECKED" ;
label define R9A1      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define R9B1      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define R9C1      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define R9D1      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define R9E1      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define R9F1      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define R9G1      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define R9H1      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define R9I1      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define R9A2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9B2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9C2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9D2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9E2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9F2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9G2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9H2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9I2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9A3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9B3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9C3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9D3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9E3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9F3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9G3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9H3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define R9I3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q47AW     -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q47BW     -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q47CW     -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q47DW     -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q47EW     -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q47FW     -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q47GW     -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q47HW     -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q47IW     -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define BOXE      1 "ONLY ONE TYPE OF CARE OFFERED"
                       2 "MORE THAN ONE TYPE OF CARE OFFERED" ;
label define Q48A      -9 "INAPPLICABLE, BOX E CODED 1" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q48B      -9 "INAPPLICABLE, BOX E CODED 1" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q48C      -9 "INAPPLICABLE, BOX E CODED 1" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q48D      -9 "INAPPLICABLE, BOX E CODED 1" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q48E      -9 "INAPPLICABLE, BOX E CODED 1" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q49A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -1 "MORE THAN ONE SALARY GIVEN" ;
label define Q49AU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "PER HOUR" 4 "PER YEAR" ;
label define Q50A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q49B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -1 "MORE THAN ONE SALARY GIVEN" ;
label define Q49BU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "PER HOUR" 4 "PER YEAR" ;
label define Q50B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q49C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -1 "MORE THAN ONE SALARY GIVEN" ;
label define Q49CU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "PER HOUR" 4 "PER YEAR" ;
label define Q50C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q49D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -1 "MORE THAN ONE SALARY GIVEN" ;
label define Q49DU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "PER HOUR" 4 "PER YEAR" ;
label define Q50D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q49E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -1 "MORE THAN ONE SALARY GIVEN" ;
label define Q49EU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "PER HOUR" 4 "PER YEAR" ;
label define Q50E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q49F      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -1 "MORE THAN ONE SALARY GIVEN" ;
label define Q49FU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "PER HOUR" 4 "PER YEAR" ;
label define Q50F      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q49G      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -1 "MORE THAN ONE SALARY GIVEN" ;
label define Q49GU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "PER HOUR" 4 "PER YEAR" ;
label define Q50G      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q49H      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -1 "MORE THAN ONE SALARY GIVEN" ;
label define Q49HU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "PER HOUR" 4 "PER YEAR" ;
label define Q50H      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51A      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51APC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51B      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51BPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51C      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51CPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51D      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51DPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51E      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51EPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51F      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51FPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51G      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51GPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51H      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51HPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51I      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51IPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51J      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51JPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51K      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51KPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51L      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51LPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51M      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51MPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51N      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51NPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51O      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51OPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51P      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51PPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51Q      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51QPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q51R      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define Q51RPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q52       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q53FMM    -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q53FDD    -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q53FYY    -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q53TMM    -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q53TDD    -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q53TYY    -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q54BOX    -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "BOX IS CHECKED" 2 "BOX IS NOT CHECKED" ;
label define Q54PC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q55       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define Q56BOX    -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "BOX IS CHECKED" 2 "BOX IS NOT CHECKED" ;
label define Q56PC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define TMEH      -7 "NOT ASCERTAINED"
                       95 "MULTIPLE SESSIONS TO COMPLETE" ;
label define TMEM      -7 "NOT ASCERTAINED"
                       95 "MULTIPLE SESSIONS TO COMPLETE" ;
label define TMEAP     -7 "NOT ASCERTAINED" 1 "AM" 2 "PM"
                       5 "MULTIPLE SESSIONS" ;
label define Q57FMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57FDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57FYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57TMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57TDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57TYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57A01    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q57B01N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57B01P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57A02    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q57B02N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57B02P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57A03    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q57B03N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57B03P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57A04    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q57B04N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57B04P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57A05    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q57B05N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57B05P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57A06    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q57B06N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57B06P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57A07    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q57B07N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57B07P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57A08    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q57B08N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57B08P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57A09    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q57A09S   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "SPECIFIC NAMED SOURCE"
                       2 "GENERIC SOURCE"
                       3 "CHARITY/CONTRIBUTIONS/FUNDRAISING" 4 "GRANTS"
                       5 "INSURANCE - NOT FURTHER CLASSIFIED"
                       96 "MISCELLANEOUS" ;
label define Q57B09N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57B09P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57A10    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q57B10N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57B10P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q57BTN    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58FMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58FDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58FYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58TMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58TDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58TYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58A01    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q58B01N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58B01P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58A02    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q58B02N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58B02P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58A03    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q58B03N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58B03P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58A04    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q58B04N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58B04P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58A05    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q58B05N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58B05P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58A06    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q58B06N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58B06P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58A07    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q58B07N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58B07P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58A08    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q58B08N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58B08P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58A09    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q58A09S   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "SPECIFIC NAMED SOURCE"
                       2 "GENERIC SOURCE"
                       3 "CHARITY/CONTRIBUTIONS/FUNDRAISING" 4 "GRANTS"
                       5 "INSURANCE - NOT FURTHER CLASSIFIED"
                       96 "MISCELLANEOUS" ;
label define Q58B09N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58B09P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58A10    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q58B10N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58B10P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q58BTN    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59FMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59FDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59FYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59TMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59TDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59TYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59A01    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q59B01N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59B01P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59A02    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q59B02N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59B02P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59A03    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q59B03N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59B03P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59A04    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q59B04N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59B04P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59A05    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q59B05N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59B05P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59A06    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q59B06N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59B06P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59A07    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q59B07N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59B07P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59A08    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q59B08N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59B08P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59A09    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q59A09S   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "SPECIFIC NAMED SOURCE"
                       2 "GENERIC SOURCE"
                       3 "CHARITY/CONTRIBUTIONS/FUNDRAISING" 4 "GRANTS"
                       5 "INSURANCE - NOT FURTHER CLASSIFIED"
                       96 "MISCELLANEOUS" ;
label define Q59B09N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59B09P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59A10    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q59B10N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59B10P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q59BTN    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q60       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61FMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61FDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61FYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61TMM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61TDD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61TYY    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61A01    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q61B01N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61B01P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61A02    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q61B02N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61B02P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61A03    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q61B03N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61B03P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61A04    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q61B04N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61B04P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61A05    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q61B05N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61B05P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61A06    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q61B06N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61B06P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61A07    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q61B07N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61B07P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61A08    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q61B08N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61B08P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61A09    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q61A09S   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "SPECIFIC NAMED SOURCE"
                       2 "GENERIC SOURCE"
                       3 "CHARITY/CONTRIBUTIONS/FUNDRAISING" 4 "GRANTS"
                       5 "INSURANCE - NOT FURTHER CLASSIFIED"
                       96 "MISCELLANEOUS" ;
label define Q61B09N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61B09P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61A10    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q61B10N   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61B10P   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define Q61BTN    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define BIGNT     -9 "MISSING" ;
label define SMALLNT   -9 "MISSING" ;
label define PSUTYPE2  1 "METRO CERTAINTY" 2 "METRO NONCERTAINTY"
                       3 "NONMETRO NONCERTAINTY" ;
label define CENREG    1 "NORTHEAST" 2 "MIDWEST" 3 "SOUTH" 4 "WEST" ;
label define CTCLIENT  1 "NUMBER OF CLIENTS BETWEEN 0 AND 16"
                       2 "NUMBER OF CLIENTS BETWEEN 17 AND 40"
                       3 "NUMBER OF CLIENTS BETWEEN 41 AND 100"
                       4 "NUMBER OF CLIENTS BETWEEN 101 AND 225"
                       5 "NUMBER OF CLIENTS OVER 225" ;
label define FACTYPE   2 "FACILITY OFFERS RESIDENTIAL TREATMENT ON"
                       3 "FACILITY OFFERS OUTPATIENT METHADONE TRE"
                       4 "FACILITY OFFERS OUTPATIENT NON-METHADONE"
                       5 "FACILITY OFFERS MORE THAN ONE TYPE OF TR" ;
label define QFSTRAT   2 "STRATUM 2 RESIDENTIAL"
                       3 "STRATUM 3 PREDOMINANTLY OUTPATIENT METHA"
                       4 "STRATUM 4 OP NON-METH PREDOMINANTLY ALC"
                       5 "STRATUM 5 OP NON-METH - NOT IN STRATUM"
                       6 "STRATUM 6 COMBINATION" ;
label define STUDYIND  0 "INCENTIVE STUDY FACILITY" 1 "MAIN STUDY FACILITY" ;
label define OWN       1 "PRIVATE FOR PROFIT" 2 "PRIVATE NONPROFIT"
                       3 "PUBLIC" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace Q1 = . if (Q1 <= -6 )
replace Q2A = . if (Q2A <= -6 )
replace Q2B = . if (Q2B <= -6 )
replace Q2C = . if (Q2C <= -6 )
replace Q2D = . if (Q2D <= -6 )
replace Q3A = . if (Q3A <= -6 )
replace Q3B = . if (Q3B <= -6 )
replace Q3C = . if (Q3C <= -6 )
replace Q3D = . if (Q3D <= -6 )
replace Q3TOT = . if (Q3TOT <= -6 )
replace Q4A = . if (Q4A <= -6 )
replace Q4B = . if (Q4B <= -6 )
replace Q4C = . if (Q4C <= -6 )
replace Q4D = . if (Q4D <= -6 )
replace Q4E = . if (Q4E <= -6 )
replace Q4F = . if (Q4F <= -6 )
replace Q4G = . if (Q4G <= -6 )
replace Q4H = . if (Q4H <= -6 )
replace Q4I = . if (Q4I <= -6 )
replace Q4J = . if (Q4J <= -6 )
replace Q4K = . if (Q4K <= -6 )
replace BOXA = . if (BOXA <= -6 )
replace BOXB = . if (BOXB <= -6 )
replace BOXC = . if (BOXC <= -6 )
replace BOXD = . if (BOXD <= -6 )
replace Q5A = . if (Q5A <= -6 )
replace Q5B = . if (Q5B <= -6 )
replace Q5C = . if (Q5C <= -6 )
replace Q6A = . if (Q6A <= -6 )
replace Q6B = . if (Q6B <= -6 )
replace Q6C = . if (Q6C <= -6 )
replace Q7A = . if (Q7A <= -6 )
replace Q7AU = . if (Q7AU <= -6 )
replace Q7B = . if (Q7B <= -6.0 )
replace Q7BU = . if (Q7BU <= -6 )
replace Q7C = . if (Q7C <= -6 )
replace Q7CU = . if (Q7CU <= -6 )
replace Q8FMM = . if (Q8FMM <= -6 )
replace Q8FDD = . if (Q8FDD <= -6 )
replace Q8FYY = . if (Q8FYY <= -6 )
replace Q8TMM = . if (Q8TMM <= -6 )
replace Q8TDD = . if (Q8TDD <= -6 )
replace Q8TYY = . if (Q8TYY <= -6 )
replace Q9A = . if (Q9A <= -6 )
replace Q9B = . if (Q9B <= -6 )
replace Q9C = . if (Q9C <= -6 )
replace Q9D = . if (Q9D <= -6 )
replace Q10A = . if (Q10A <= -6 )
replace Q11A = . if (Q11A <= -6 )
replace Q10B = . if (Q10B <= -6 )
replace Q11B = . if (Q11B <= -6 )
replace Q10C = . if (Q10C <= -6 )
replace Q11C = . if (Q11C <= -6 )
replace Q10D = . if (Q10D <= -6 )
replace Q11D = . if (Q11D <= -6 )
replace Q10E = . if (Q10E <= -6 )
replace Q10ES = . if (Q10ES <= -6 )
replace Q11E = . if (Q11E <= -1 )
replace Q12A = . if (Q12A <= -6 )
replace Q12B = . if (Q12B <= -6 )
replace Q12C = . if (Q12C <= -6 )
replace Q13A = . if (Q13A <= -6 )
replace Q13B = . if (Q13B <= -6 )
replace Q13C = . if (Q13C <= -6 )
replace Q14 = . if (Q14 <= -6 )
replace Q15A = . if (Q15A <= -6 )
replace Q15AU = . if (Q15AU <= -6 )
replace Q15B = . if (Q15B <= -6 )
replace Q15BU = . if (Q15BU <= -6 )
replace Q15C = . if (Q15C <= -6 )
replace Q15CU = . if (Q15CU <= -6 )
replace Q16FMM = . if (Q16FMM <= -6 )
replace Q16FDD = . if (Q16FDD <= -6 )
replace Q16FYY = . if (Q16FYY <= -6 )
replace Q16TMM = . if (Q16TMM <= -6 )
replace Q16TDD = . if (Q16TDD <= -6 )
replace Q16TYY = . if (Q16TYY <= -6 )
replace Q17A = . if (Q17A <= -6 )
replace Q17B = . if (Q17B <= -6 )
replace Q17C = . if (Q17C <= -6.0 )
replace Q17D = . if (Q17D <= -6.0 )
replace Q18A = . if (Q18A <= -6 )
replace Q19A = . if (Q19A <= -6 )
replace Q18B = . if (Q18B <= -6 )
replace Q19B = . if (Q19B <= -6.0 )
replace Q18C = . if (Q18C <= -6 )
replace Q19C = . if (Q19C <= -6 )
replace Q18D = . if (Q18D <= -6 )
replace Q19D = . if (Q19D <= -6 )
replace Q18E = . if (Q18E <= -6 )
replace Q18ES = . if (Q18ES <= -6 )
replace Q19E = . if (Q19E <= -6.0 )
replace Q20 = . if (Q20 <= -6 )
replace Q21 = . if (Q21 <= -1.0 )
replace Q21U = . if (Q21U <= -6 )
replace Q22FMM = . if (Q22FMM <= -6 )
replace Q22FDD = . if (Q22FDD <= -6 )
replace Q22FYY = . if (Q22FYY <= -6 )
replace Q22TMM = . if (Q22TMM <= -6 )
replace Q22TDD = . if (Q22TDD <= -6 )
replace Q22TYY = . if (Q22TYY <= -6 )
replace Q23A = . if (Q23A <= -6.00 )
replace Q23B = . if (Q23B <= -6.00 )
replace Q24A = . if (Q24A <= -6 )
replace Q25A = . if (Q25A <= -6.0 )
replace Q24B = . if (Q24B <= -6 )
replace Q25B = . if (Q25B <= -6.0 )
replace Q24C = . if (Q24C <= -6 )
replace Q25C = . if (Q25C <= -6.0 )
replace Q24D = . if (Q24D <= -6 )
replace Q25D = . if (Q25D <= -6.0 )
replace Q24E = . if (Q24E <= -6 )
replace Q24ES = . if (Q24ES <= -6 )
replace Q25E = . if (Q25E <= -6.00 )
replace Q26 = . if (Q26 <= -6.0 )
replace Q27 = . if (Q27 <= -6 )
replace Q28 = . if (Q28 <= -1.00 )
replace Q28U = . if (Q28U <= -6 )
replace Q29 = . if (Q29 <= -6 )
replace Q30 = . if (Q30 <= -6 )
replace Q31 = . if (Q31 <= -6 )
replace Q31U = . if (Q31U <= -6 )
replace Q32FMM = . if (Q32FMM <= -6 )
replace Q32FDD = . if (Q32FDD <= -6 )
replace Q32FYY = . if (Q32FYY <= -6 )
replace Q32TMM = . if (Q32TMM <= -6 )
replace Q32TDD = . if (Q32TDD <= -6 )
replace Q32TYY = . if (Q32TYY <= -6 )
replace Q33A = . if (Q33A <= -1.00 )
replace Q33B = . if (Q33B <= -1.00 )
replace Q34A = . if (Q34A <= -6 )
replace Q35A = . if (Q35A <= -6.0 )
replace Q34B = . if (Q34B <= -6 )
replace Q35B = . if (Q35B <= -6.0 )
replace Q34C = . if (Q34C <= -6 )
replace Q35C = . if (Q35C <= -6.0 )
replace Q34D = . if (Q34D <= -6 )
replace Q35D = . if (Q35D <= -6 )
replace Q34E = . if (Q34E <= -6 )
replace Q34ES = . if (Q34ES <= -6 )
replace Q35E = . if (Q35E <= -6.00 )
replace Q36 = . if (Q36 <= -6 )
replace Q37 = . if (Q37 <= -6.0 )
replace Q38 = . if (Q38 <= -6.00 )
replace Q39 = . if (Q39 <= -6.00 )
replace Q40A = . if (Q40A <= -6 )
replace Q40B = . if (Q40B <= -6 )
replace Q40C = . if (Q40C <= -6 )
replace Q41 = . if (Q41 <= -6 )
replace Q42A = . if (Q42A <= -6 )
replace Q42B = . if (Q42B <= -6 )
replace Q42C = . if (Q42C <= -6 )
replace Q42D = . if (Q42D <= -6 )
replace Q42E = . if (Q42E <= -6 )
replace Q42F = . if (Q42F <= -6 )
replace Q42G = . if (Q42G <= -6 )
replace Q42H = . if (Q42H <= -6 )
replace Q42I = . if (Q42I <= -6 )
replace Q42J = . if (Q42J <= -6 )
replace Q43 = . if (Q43 <= -6 )
replace Q44 = . if (Q44 <= -6 )
replace Q45 = . if (Q45 <= -6 )
replace Q45B = . if (Q45B <= -6 )
replace Q45C = . if (Q45C <= -6 )
replace Q46 = . if (Q46 <= -6 )
replace Q46OTH1 = . if (Q46OTH1 <= -6 )
replace Q46OTH2 = . if (Q46OTH2 <= -6 )
replace Q46OTH3 = . if (Q46OTH3 <= -6 )
replace Q47BOX = . if (Q47BOX <= -6 )
replace R9A1 = . if (R9A1 <= -6.00 )
replace R9B1 = . if (R9B1 <= -6.0 )
replace R9C1 = . if (R9C1 <= -6.0 )
replace R9D1 = . if (R9D1 <= -6.00 )
replace R9E1 = . if (R9E1 <= -6.00 )
replace R9F1 = . if (R9F1 <= -6.00 )
replace R9G1 = . if (R9G1 <= -6.0 )
replace R9H1 = . if (R9H1 <= -6.00 )
replace R9I1 = . if (R9I1 <= -6.00 )
replace R9A2 = . if (R9A2 <= -6 )
replace R9B2 = . if (R9B2 <= -6 )
replace R9C2 = . if (R9C2 <= -6 )
replace R9D2 = . if (R9D2 <= -6 )
replace R9E2 = . if (R9E2 <= -6.0 )
replace R9F2 = . if (R9F2 <= -6 )
replace R9G2 = . if (R9G2 <= -6 )
replace R9H2 = . if (R9H2 <= -6 )
replace R9I2 = . if (R9I2 <= -6.0 )
replace R9A3 = . if (R9A3 <= -6 )
replace R9B3 = . if (R9B3 <= -6 )
replace R9C3 = . if (R9C3 <= -6 )
replace R9D3 = . if (R9D3 <= -6 )
replace R9E3 = . if (R9E3 <= -6 )
replace R9F3 = . if (R9F3 <= -6 )
replace R9G3 = . if (R9G3 <= -6 )
replace R9H3 = . if (R9H3 <= -6.0 )
replace R9I3 = . if (R9I3 <= -6.0 )
replace Q47AW = . if (Q47AW <= -6.00 )
replace Q47BW = . if (Q47BW <= -6.00 )
replace Q47CW = . if (Q47CW <= -6.0 )
replace Q47DW = . if (Q47DW <= -6.0 )
replace Q47EW = . if (Q47EW <= -6.00 )
replace Q47FW = . if (Q47FW <= -6.0 )
replace Q47GW = . if (Q47GW <= -6.0 )
replace Q47HW = . if (Q47HW <= -6.0 )
replace Q47IW = . if (Q47IW <= -6.00 )
replace BOXE = . if (BOXE <= -6 )
replace Q48A = . if (Q48A <= -6 )
replace Q48B = . if (Q48B <= -6 )
replace Q48C = . if (Q48C <= -6 )
replace Q48D = . if (Q48D <= -6 )
replace Q48E = . if (Q48E <= -6 )
replace Q49A = . if (Q49A <= -1.00 )
replace Q49AU = . if (Q49AU <= -6 )
replace Q50A = . if (Q50A <= -6 )
replace Q49B = . if (Q49B <= -1.00 )
replace Q49BU = . if (Q49BU <= -6.00 )
replace Q50B = . if (Q50B <= -6.00 )
replace Q49C = . if (Q49C <= -1.00 )
replace Q49CU = . if (Q49CU <= -6.00 )
replace Q50C = . if (Q50C <= -6.00 )
replace Q49D = . if (Q49D <= -1.00 )
replace Q49DU = . if (Q49DU <= -6.00 )
replace Q50D = . if (Q50D <= -6.00 )
replace Q49E = . if (Q49E <= -1.00 )
replace Q49EU = . if (Q49EU <= -6.00 )
replace Q50E = . if (Q50E <= -6.00 )
replace Q49F = . if (Q49F <= -1.00 )
replace Q49FU = . if (Q49FU <= -6.00 )
replace Q50F = . if (Q50F <= -6.00 )
replace Q49G = . if (Q49G <= -1.00 )
replace Q49GU = . if (Q49GU <= -6.00 )
replace Q50G = . if (Q50G <= -6.00 )
replace Q49H = . if (Q49H <= -1.00 )
replace Q49HU = . if (Q49HU <= -6 )
replace Q50H = . if (Q50H <= -6 )
replace Q51A = . if (Q51A <= -6 )
replace Q51APC = . if (Q51APC <= -6 )
replace Q51B = . if (Q51B <= -6 )
replace Q51BPC = . if (Q51BPC <= -6 )
replace Q51C = . if (Q51C <= -6 )
replace Q51CPC = . if (Q51CPC <= -6.0 )
replace Q51D = . if (Q51D <= -6 )
replace Q51DPC = . if (Q51DPC <= -6 )
replace Q51E = . if (Q51E <= -6 )
replace Q51EPC = . if (Q51EPC <= -6.00 )
replace Q51F = . if (Q51F <= -6 )
replace Q51FPC = . if (Q51FPC <= -6.00 )
replace Q51G = . if (Q51G <= -6 )
replace Q51GPC = . if (Q51GPC <= -6.00 )
replace Q51H = . if (Q51H <= -6 )
replace Q51HPC = . if (Q51HPC <= -6.00 )
replace Q51I = . if (Q51I <= -6 )
replace Q51IPC = . if (Q51IPC <= -6.0 )
replace Q51J = . if (Q51J <= -6 )
replace Q51JPC = . if (Q51JPC <= -6 )
replace Q51K = . if (Q51K <= -6 )
replace Q51KPC = . if (Q51KPC <= -6.0 )
replace Q51L = . if (Q51L <= -6 )
replace Q51LPC = . if (Q51LPC <= -6.0 )
replace Q51M = . if (Q51M <= -6 )
replace Q51MPC = . if (Q51MPC <= -6.0 )
replace Q51N = . if (Q51N <= -6 )
replace Q51NPC = . if (Q51NPC <= -6.0 )
replace Q51O = . if (Q51O <= -6 )
replace Q51OPC = . if (Q51OPC <= -6.0 )
replace Q51P = . if (Q51P <= -6 )
replace Q51PPC = . if (Q51PPC <= -6 )
replace Q51Q = . if (Q51Q <= -6 )
replace Q51QPC = . if (Q51QPC <= -6.0 )
replace Q51R = . if (Q51R <= -6 )
replace Q51RPC = . if (Q51RPC <= -6 )
replace Q52 = . if (Q52 <= -1 )
replace Q53FMM = . if (Q53FMM <= -6 )
replace Q53FDD = . if (Q53FDD <= -6 )
replace Q53FYY = . if (Q53FYY <= -6 )
replace Q53TMM = . if (Q53TMM <= -6 )
replace Q53TDD = . if (Q53TDD <= -6 )
replace Q53TYY = . if (Q53TYY <= -6 )
replace Q54BOX = . if (Q54BOX <= -6 )
replace Q54PC = . if (Q54PC <= -6 )
replace Q55 = . if (Q55 <= -1 )
replace Q56BOX = . if (Q56BOX <= -6 )
replace Q56PC = . if (Q56PC <= -6 )
replace TMEH = . if (TMEH <= -6 )
replace TMEM = . if (TMEM <= -6 )
replace TMEAP = . if (TMEAP <= -6 )
replace Q57FMM = . if (Q57FMM <= -6 )
replace Q57FDD = . if (Q57FDD <= -6 )
replace Q57FYY = . if (Q57FYY <= -6 )
replace Q57TMM = . if (Q57TMM <= -6 )
replace Q57TDD = . if (Q57TDD <= -6 )
replace Q57TYY = . if (Q57TYY <= -6 )
replace Q57A01 = . if (Q57A01 <= -6 )
replace Q57B01N = . if (Q57B01N <= -6 )
replace Q57B01P = . if (Q57B01P <= -6 )
replace Q57A02 = . if (Q57A02 <= -6 )
replace Q57B02N = . if (Q57B02N <= -6 )
replace Q57B02P = . if (Q57B02P <= -6 )
replace Q57A03 = . if (Q57A03 <= -6 )
replace Q57B03N = . if (Q57B03N <= -6 )
replace Q57B03P = . if (Q57B03P <= -6 )
replace Q57A04 = . if (Q57A04 <= -6 )
replace Q57B04N = . if (Q57B04N <= -6 )
replace Q57B04P = . if (Q57B04P <= -6 )
replace Q57A05 = . if (Q57A05 <= -6 )
replace Q57B05N = . if (Q57B05N <= -6 )
replace Q57B05P = . if (Q57B05P <= -6 )
replace Q57A06 = . if (Q57A06 <= -6 )
replace Q57B06N = . if (Q57B06N <= -6 )
replace Q57B06P = . if (Q57B06P <= -6 )
replace Q57A07 = . if (Q57A07 <= -6 )
replace Q57B07N = . if (Q57B07N <= -6 )
replace Q57B07P = . if (Q57B07P <= -6 )
replace Q57A08 = . if (Q57A08 <= -6 )
replace Q57B08N = . if (Q57B08N <= -6 )
replace Q57B08P = . if (Q57B08P <= -6 )
replace Q57A09 = . if (Q57A09 <= -6 )
replace Q57A09S = . if (Q57A09S <= -6 )
replace Q57B09N = . if (Q57B09N <= -6 )
replace Q57B09P = . if (Q57B09P <= -6 )
replace Q57A10 = . if (Q57A10 <= -6 )
replace Q57B10N = . if (Q57B10N <= -6 )
replace Q57B10P = . if (Q57B10P <= -6 )
replace Q57BTN = . if (Q57BTN <= -6 )
replace Q58FMM = . if (Q58FMM <= -6 )
replace Q58FDD = . if (Q58FDD <= -6 )
replace Q58FYY = . if (Q58FYY <= -6 )
replace Q58TMM = . if (Q58TMM <= -6 )
replace Q58TDD = . if (Q58TDD <= -6 )
replace Q58TYY = . if (Q58TYY <= -6 )
replace Q58A01 = . if (Q58A01 <= -6 )
replace Q58B01N = . if (Q58B01N <= -6 )
replace Q58B01P = . if (Q58B01P <= -6 )
replace Q58A02 = . if (Q58A02 <= -6 )
replace Q58B02N = . if (Q58B02N <= -6 )
replace Q58B02P = . if (Q58B02P <= -6 )
replace Q58A03 = . if (Q58A03 <= -6 )
replace Q58B03N = . if (Q58B03N <= -6 )
replace Q58B03P = . if (Q58B03P <= -6 )
replace Q58A04 = . if (Q58A04 <= -6 )
replace Q58B04N = . if (Q58B04N <= -6 )
replace Q58B04P = . if (Q58B04P <= -6 )
replace Q58A05 = . if (Q58A05 <= -6 )
replace Q58B05N = . if (Q58B05N <= -6 )
replace Q58B05P = . if (Q58B05P <= -6 )
replace Q58A06 = . if (Q58A06 <= -6 )
replace Q58B06N = . if (Q58B06N <= -6 )
replace Q58B06P = . if (Q58B06P <= -6 )
replace Q58A07 = . if (Q58A07 <= -6 )
replace Q58B07N = . if (Q58B07N <= -6 )
replace Q58B07P = . if (Q58B07P <= -6 )
replace Q58A08 = . if (Q58A08 <= -6 )
replace Q58B08N = . if (Q58B08N <= -6 )
replace Q58B08P = . if (Q58B08P <= -6 )
replace Q58A09 = . if (Q58A09 <= -6 )
replace Q58A09S = . if (Q58A09S <= -6 )
replace Q58B09N = . if (Q58B09N <= -6 )
replace Q58B09P = . if (Q58B09P <= -6 )
replace Q58A10 = . if (Q58A10 <= -6 )
replace Q58B10N = . if (Q58B10N <= -6 )
replace Q58B10P = . if (Q58B10P <= -6 )
replace Q58BTN = . if (Q58BTN <= -6 )
replace Q59FMM = . if (Q59FMM <= -6 )
replace Q59FDD = . if (Q59FDD <= -6 )
replace Q59FYY = . if (Q59FYY <= -6 )
replace Q59TMM = . if (Q59TMM <= -6 )
replace Q59TDD = . if (Q59TDD <= -6 )
replace Q59TYY = . if (Q59TYY <= -6 )
replace Q59A01 = . if (Q59A01 <= -6 )
replace Q59B01N = . if (Q59B01N <= -6 )
replace Q59B01P = . if (Q59B01P <= -6 )
replace Q59A02 = . if (Q59A02 <= -6 )
replace Q59B02N = . if (Q59B02N <= -6 )
replace Q59B02P = . if (Q59B02P <= -6 )
replace Q59A03 = . if (Q59A03 <= -6 )
replace Q59B03N = . if (Q59B03N <= -6 )
replace Q59B03P = . if (Q59B03P <= -6 )
replace Q59A04 = . if (Q59A04 <= -6 )
replace Q59B04N = . if (Q59B04N <= -6 )
replace Q59B04P = . if (Q59B04P <= -6 )
replace Q59A05 = . if (Q59A05 <= -6 )
replace Q59B05N = . if (Q59B05N <= -6 )
replace Q59B05P = . if (Q59B05P <= -6 )
replace Q59A06 = . if (Q59A06 <= -6 )
replace Q59B06N = . if (Q59B06N <= -6 )
replace Q59B06P = . if (Q59B06P <= -6 )
replace Q59A07 = . if (Q59A07 <= -6 )
replace Q59B07N = . if (Q59B07N <= -6 )
replace Q59B07P = . if (Q59B07P <= -6 )
replace Q59A08 = . if (Q59A08 <= -6 )
replace Q59B08N = . if (Q59B08N <= -6 )
replace Q59B08P = . if (Q59B08P <= -6 )
replace Q59A09 = . if (Q59A09 <= -6 )
replace Q59A09S = . if (Q59A09S <= -6 )
replace Q59B09N = . if (Q59B09N <= -6 )
replace Q59B09P = . if (Q59B09P <= -6 )
replace Q59A10 = . if (Q59A10 <= -6 )
replace Q59B10N = . if (Q59B10N <= -6 )
replace Q59B10P = . if (Q59B10P <= -6 )
replace Q59BTN = . if (Q59BTN <= -6 )
replace Q60 = . if (Q60 <= -6 )
replace Q61FMM = . if (Q61FMM <= -6 )
replace Q61FDD = . if (Q61FDD <= -6 )
replace Q61FYY = . if (Q61FYY <= -6 )
replace Q61TMM = . if (Q61TMM <= -6 )
replace Q61TDD = . if (Q61TDD <= -6 )
replace Q61TYY = . if (Q61TYY <= -6 )
replace Q61A01 = . if (Q61A01 <= -6 )
replace Q61B01N = . if (Q61B01N <= -6 )
replace Q61B01P = . if (Q61B01P <= -6 )
replace Q61A02 = . if (Q61A02 <= -6 )
replace Q61B02N = . if (Q61B02N <= -6 )
replace Q61B02P = . if (Q61B02P <= -6 )
replace Q61A03 = . if (Q61A03 <= -6 )
replace Q61B03N = . if (Q61B03N <= -6 )
replace Q61B03P = . if (Q61B03P <= -6 )
replace Q61A04 = . if (Q61A04 <= -6 )
replace Q61B04N = . if (Q61B04N <= -6 )
replace Q61B04P = . if (Q61B04P <= -6 )
replace Q61A05 = . if (Q61A05 <= -6 )
replace Q61B05N = . if (Q61B05N <= -6 )
replace Q61B05P = . if (Q61B05P <= -6 )
replace Q61A06 = . if (Q61A06 <= -6 )
replace Q61B06N = . if (Q61B06N <= -6 )
replace Q61B06P = . if (Q61B06P <= -6 )
replace Q61A07 = . if (Q61A07 <= -6 )
replace Q61B07N = . if (Q61B07N <= -6 )
replace Q61B07P = . if (Q61B07P <= -6 )
replace Q61A08 = . if (Q61A08 <= -6 )
replace Q61B08N = . if (Q61B08N <= -6 )
replace Q61B08P = . if (Q61B08P <= -6 )
replace Q61A09 = . if (Q61A09 <= -6 )
replace Q61A09S = . if (Q61A09S <= -6 )
replace Q61B09N = . if (Q61B09N <= -6 )
replace Q61B09P = . if (Q61B09P <= -6 )
replace Q61A10 = . if (Q61A10 <= -6 )
replace Q61B10N = . if (Q61B10N <= -6 )
replace Q61B10P = . if (Q61B10P <= -6 )
replace Q61BTN = . if (Q61BTN <= -6 )
replace BIG_N = . if (BIG_N <= -6 )
replace SMALL_N = . if (SMALL_N <= -6 )
replace BIGNT = . if (BIGNT <= -6 )
replace SMALLNT = . if (SMALLNT <= -6 )
replace PSUTYPE2 = . if (PSUTYPE2 <= -6 )
replace COMPWT62 = . if (COMPWT62 <= -6.0000 )
replace CENREG = . if (CENREG <= -6 )
replace PH1FW0 = . if (PH1FW0 <= -6.0000 )
replace PH2CFW = . if (PH2CFW <= -6.0000 )
replace F2BWA0 = . if (F2BWA0 <= -6.0000 )
replace VST_PSU = . if (VST_PSU <= -6 )
replace VUN_PSU = . if (VUN_PSU <= -6 )
replace CTCLIENT = . if (CTCLIENT <= -6 )
replace FACTYPE = . if (FACTYPE <= -6 )
replace TRIMFAC0 = . if (TRIMFAC0 <= -6.0000 )
replace CTRLCAT2 = . if (CTRLCAT2 <= -6 )
replace FTOTCNT = . if (FTOTCNT <= -6 )
replace FSMPCNT = . if (FSMPCNT <= -6 )
replace PSF = . if (PSF <= -6.0000 )
replace F2FWA1 = . if (F2FWA1 <= -6.0000 )
replace F2FWA2 = . if (F2FWA2 <= -6.0000 )
replace F2FWA3 = . if (F2FWA3 <= -6.0000 )
replace F2FWA4 = . if (F2FWA4 <= -6.0000 )
replace F2FWA5 = . if (F2FWA5 <= -6.0000 )
replace F2FWA6 = . if (F2FWA6 <= -6.0000 )
replace F2FWA7 = . if (F2FWA7 <= -6.0000 )
replace F2FWA8 = . if (F2FWA8 <= -6.0000 )
replace F2FWA9 = . if (F2FWA9 <= -6.0000 )
replace F2FWA10 = . if (F2FWA10 <= -6.0000 )
replace F2FWA11 = . if (F2FWA11 <= -6.0000 )
replace F2FWA12 = . if (F2FWA12 <= -6.0000 )
replace F2FWA13 = . if (F2FWA13 <= -6.0000 )
replace F2FWA14 = . if (F2FWA14 <= -6.0000 )
replace F2FWA15 = . if (F2FWA15 <= -6.0000 )
replace F2FWA16 = . if (F2FWA16 <= -6.0000 )
replace F2FWA17 = . if (F2FWA17 <= -6.0000 )
replace F2FWA18 = . if (F2FWA18 <= -6.0000 )
replace F2FWA19 = . if (F2FWA19 <= -6.0000 )
replace F2FWA20 = . if (F2FWA20 <= -6.0000 )
replace F2FWA21 = . if (F2FWA21 <= -6.0000 )
replace F2FWA22 = . if (F2FWA22 <= -6.0000 )
replace F2FWA23 = . if (F2FWA23 <= -6.0000 )
replace F2FWA24 = . if (F2FWA24 <= -6.0000 )
replace F2FWA25 = . if (F2FWA25 <= -6.0000 )
replace F2FWA26 = . if (F2FWA26 <= -6.0000 )
replace F2FWA27 = . if (F2FWA27 <= -6.0000 )
replace F2FWA28 = . if (F2FWA28 <= -6.0000 )
replace F2FWA29 = . if (F2FWA29 <= -6.0000 )
replace F2FWA30 = . if (F2FWA30 <= -6.0000 )
replace F2FWA31 = . if (F2FWA31 <= -6.0000 )
replace F2FWA32 = . if (F2FWA32 <= -6.0000 )
replace F2FWA33 = . if (F2FWA33 <= -6.0000 )
replace F2FWA34 = . if (F2FWA34 <= -6.0000 )
replace F2FWA35 = . if (F2FWA35 <= -6.0000 )
replace F2FWA36 = . if (F2FWA36 <= -6.0000 )
replace F2FWA37 = . if (F2FWA37 <= -6.0000 )
replace F2FWA38 = . if (F2FWA38 <= -6.0000 )
replace F2FWA39 = . if (F2FWA39 <= -6.0000 )
replace F2FWA40 = . if (F2FWA40 <= -6.0000 )
replace F2FWA41 = . if (F2FWA41 <= -6.0000 )
replace F2FWA42 = . if (F2FWA42 <= -6.0000 )
replace F2FWA43 = . if (F2FWA43 <= -6.0000 )
replace F2FWA44 = . if (F2FWA44 <= -6.0000 )
replace F2FWA45 = . if (F2FWA45 <= -6.0000 )
replace F2FWA46 = . if (F2FWA46 <= -6.0000 )
replace F2FWA47 = . if (F2FWA47 <= -6.0000 )
replace F2FWA48 = . if (F2FWA48 <= -6.0000 )
replace F2FWA49 = . if (F2FWA49 <= -6.0000 )
replace F2FWA50 = . if (F2FWA50 <= -6.0000 )
replace F2FWA51 = . if (F2FWA51 <= -6.0000 )
replace F2FWA52 = . if (F2FWA52 <= -6.0000 )
replace F2FWA53 = . if (F2FWA53 <= -6.0000 )
replace F2FWA54 = . if (F2FWA54 <= -6.0000 )
replace F2FWA55 = . if (F2FWA55 <= -6.0000 )
replace F2FWA56 = . if (F2FWA56 <= -6.0000 )
replace F2FWA57 = . if (F2FWA57 <= -6.0000 )
replace F2FWA58 = . if (F2FWA58 <= -6.0000 )
replace F2FWA59 = . if (F2FWA59 <= -6.0000 )
replace F2FWA60 = . if (F2FWA60 <= -6.0000 )
replace F2FWA61 = . if (F2FWA61 <= -6.0000 )
replace F2FWA62 = . if (F2FWA62 <= -6.0000 )
replace F2FWA63 = . if (F2FWA63 <= -6.0000 )
replace F2FWA64 = . if (F2FWA64 <= -6.0000 )
replace F2FWA65 = . if (F2FWA65 <= -6.0000 )
replace F2FWA66 = . if (F2FWA66 <= -6.0000 )
replace F2FWA67 = . if (F2FWA67 <= -6.0000 )
replace F2FWA68 = . if (F2FWA68 <= -6.0000 )
replace F2FWA69 = . if (F2FWA69 <= -6.0000 )
replace F2FWA70 = . if (F2FWA70 <= -6.0000 )
replace F2FWA71 = . if (F2FWA71 <= -6.0000 )
replace F2FWA72 = . if (F2FWA72 <= -6.0000 )
replace F2FWA73 = . if (F2FWA73 <= -6.0000 )
replace F2FWA74 = . if (F2FWA74 <= -6.0000 )
replace F2FWA75 = . if (F2FWA75 <= -6.0000 )
replace F2FWA76 = . if (F2FWA76 <= -6.0000 )
replace F2FWA77 = . if (F2FWA77 <= -6.0000 )
replace F2FWA78 = . if (F2FWA78 <= -6.0000 )
replace F2FWA0 = . if (F2FWA0 <= -6.0000 )
replace OWN = . if (OWN <= -6 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

